@@ -1,4 +1,4 @@
-"""
+'''
 # aws-apigateway-kinesisstreams module
 
 <!--BEGIN STABILITY BANNER-->---
@@ -105,7 +105,7 @@ Out of the box implementation of the Construct without any override will set the
 
 
 © Copyright 2021 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-"""
+'''
 import abc
 import builtins
 import datetime
@@ -130,9 +130,9 @@ class ApiGatewayToKinesisStreams(
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-solutions-constructs/aws-apigateway-kinesisstreams.ApiGatewayToKinesisStreams",
 ):
-    """
+    '''
     :summary: The ApiGatewayToKinesisStreams class.
-    """
+    '''
 
     def __init__(
         self,
@@ -148,7 +148,7 @@ class ApiGatewayToKinesisStreams(
         put_records_request_model: typing.Optional[aws_cdk.aws_apigateway.ModelOptions] = None,
         put_records_request_template: typing.Optional[builtins.str] = None,
     ) -> None:
-        """
+        '''
         :param scope: - represents the scope for all the resources.
         :param id: - this is a a scope-unique id.
         :param api_gateway_props: Optional user-provided props to override the default props for the API Gateway. Default: - Default properties are used.
@@ -163,7 +163,7 @@ class ApiGatewayToKinesisStreams(
         :access: public
         :since: 1.62.0
         :summary: Constructs a new instance of the ApiGatewayToKinesisStreams class.
-        """
+        '''
         props = ApiGatewayToKinesisStreamsProps(
             api_gateway_props=api_gateway_props,
             existing_stream_obj=existing_stream_obj,
@@ -230,7 +230,7 @@ class ApiGatewayToKinesisStreamsProps:
         put_records_request_model: typing.Optional[aws_cdk.aws_apigateway.ModelOptions] = None,
         put_records_request_template: typing.Optional[builtins.str] = None,
     ) -> None:
-        """
+        '''
         :param api_gateway_props: Optional user-provided props to override the default props for the API Gateway. Default: - Default properties are used.
         :param existing_stream_obj: Existing instance of Kinesis Stream, if this is set then kinesisStreamProps is ignored. Default: - None
         :param kinesis_stream_props: Optional user-provided props to override the default props for the Kinesis Data Stream. Default: - Default properties are used.
@@ -241,7 +241,7 @@ class ApiGatewayToKinesisStreamsProps:
         :param put_records_request_template: API Gateway request template for the PutRecords action. If not provided, a default one will be used. Default: - { "StreamName": "${this.kinesisStream.streamName}", "Records": [ #foreach($elem in $input.path('$.records')) { "Data": "$util.base64Encode($elem.data)", "PartitionKey": "$elem.partitionKey"}#if($foreach.hasNext),#end #end ] }
 
         :summary: The properties for the ApiGatewayToKinesisStreamsProps class.
-        """
+        '''
         if isinstance(api_gateway_props, dict):
             api_gateway_props = aws_cdk.aws_apigateway.RestApiProps(**api_gateway_props)
         if isinstance(kinesis_stream_props, dict):
@@ -272,37 +272,37 @@ class ApiGatewayToKinesisStreamsProps:
 
     @builtins.property
     def api_gateway_props(self) -> typing.Optional[aws_cdk.aws_apigateway.RestApiProps]:
-        """Optional user-provided props to override the default props for the API Gateway.
+        '''Optional user-provided props to override the default props for the API Gateway.
 
         :default: - Default properties are used.
-        """
+        '''
         result = self._values.get("api_gateway_props")
         return typing.cast(typing.Optional[aws_cdk.aws_apigateway.RestApiProps], result)
 
     @builtins.property
     def existing_stream_obj(self) -> typing.Optional[aws_cdk.aws_kinesis.Stream]:
-        """Existing instance of Kinesis Stream, if this is set then kinesisStreamProps is ignored.
+        '''Existing instance of Kinesis Stream, if this is set then kinesisStreamProps is ignored.
 
         :default: - None
-        """
+        '''
         result = self._values.get("existing_stream_obj")
         return typing.cast(typing.Optional[aws_cdk.aws_kinesis.Stream], result)
 
     @builtins.property
     def kinesis_stream_props(self) -> typing.Optional[aws_cdk.aws_kinesis.StreamProps]:
-        """Optional user-provided props to override the default props for the Kinesis Data Stream.
+        '''Optional user-provided props to override the default props for the Kinesis Data Stream.
 
         :default: - Default properties are used.
-        """
+        '''
         result = self._values.get("kinesis_stream_props")
         return typing.cast(typing.Optional[aws_cdk.aws_kinesis.StreamProps], result)
 
     @builtins.property
     def log_group_props(self) -> typing.Optional[aws_cdk.aws_logs.LogGroupProps]:
-        """User provided props to override the default props for the CloudWatchLogs LogGroup.
+        '''User provided props to override the default props for the CloudWatchLogs LogGroup.
 
         :default: - Default props are used
-        """
+        '''
         result = self._values.get("log_group_props")
         return typing.cast(typing.Optional[aws_cdk.aws_logs.LogGroupProps], result)
 
@@ -310,7 +310,7 @@ class ApiGatewayToKinesisStreamsProps:
     def put_record_request_model(
         self,
     ) -> typing.Optional[aws_cdk.aws_apigateway.ModelOptions]:
-        """API Gateway request model for the PutRecord action.
+        '''API Gateway request model for the PutRecord action.
 
         If not provided, a default one will be created.
 
@@ -318,13 +318,13 @@ class ApiGatewayToKinesisStreamsProps:
 
         - {"$schema":"http://json-schema.org/draft-04/schema#","title":"PutRecord proxy single-record payload","type":"object",
         "required":["data","partitionKey"],"properties":{"data":{"type":"string"},"partitionKey":{"type":"string"}}}
-        """
+        '''
         result = self._values.get("put_record_request_model")
         return typing.cast(typing.Optional[aws_cdk.aws_apigateway.ModelOptions], result)
 
     @builtins.property
     def put_record_request_template(self) -> typing.Optional[builtins.str]:
-        """API Gateway request template for the PutRecord action.
+        '''API Gateway request template for the PutRecord action.
 
         If not provided, a default one will be used.
 
@@ -332,7 +332,7 @@ class ApiGatewayToKinesisStreamsProps:
 
         - { "StreamName": "${this.kinesisStream.streamName}", "Data": "$util.base64Encode($input.json('$.data'))",
         "PartitionKey": "$input.path('$.partitionKey')" }
-        """
+        '''
         result = self._values.get("put_record_request_template")
         return typing.cast(typing.Optional[builtins.str], result)
 
@@ -340,7 +340,7 @@ class ApiGatewayToKinesisStreamsProps:
     def put_records_request_model(
         self,
     ) -> typing.Optional[aws_cdk.aws_apigateway.ModelOptions]:
-        """API Gateway request model for the PutRecords action.
+        '''API Gateway request model for the PutRecords action.
 
         If not provided, a default one will be created.
 
@@ -349,13 +349,13 @@ class ApiGatewayToKinesisStreamsProps:
         - {"$schema":"http://json-schema.org/draft-04/schema#","title":"PutRecords proxy payload data","type":"object","required":["records"],
         "properties":{"records":{"type":"array","items":{"type":"object",
         "required":["data","partitionKey"],"properties":{"data":{"type":"string"},"partitionKey":{"type":"string"}}}}}}
-        """
+        '''
         result = self._values.get("put_records_request_model")
         return typing.cast(typing.Optional[aws_cdk.aws_apigateway.ModelOptions], result)
 
     @builtins.property
     def put_records_request_template(self) -> typing.Optional[builtins.str]:
-        """API Gateway request template for the PutRecords action.
+        '''API Gateway request template for the PutRecords action.
 
         If not provided, a default one will be used.
 
@@ -363,7 +363,7 @@ class ApiGatewayToKinesisStreamsProps:
 
         - { "StreamName": "${this.kinesisStream.streamName}", "Records": [ #foreach($elem in $input.path('$.records'))
         { "Data": "$util.base64Encode($elem.data)", "PartitionKey": "$elem.partitionKey"}#if($foreach.hasNext),#end #end ] }
-        """
+        '''
         result = self._values.get("put_records_request_template")
         return typing.cast(typing.Optional[builtins.str], result)
 
